From 8b44783b65ea12b8c55800b6c93682640fd65388 Mon Sep 17 00:00:00 2001
From: Marko Lindqvist <cazfi74@gmail.com>
Date: Thu, 21 Nov 2024 03:48:17 +0200
Subject: [PATCH 78/78] Rename Pearl Harbour rule as Pearl Harbor

See RM #1149

Signed-off-by: Marko Lindqvist <cazfi74@gmail.com>
---
 ai/default/daimilitary.c         |  6 +++---
 common/combat.c                  |  6 +++---
 common/networking/packets.def    |  2 +-
 data/alien/game.ruleset          |  2 +-
 data/alien/units.ruleset         |  2 +-
 data/civ1/game.ruleset           |  2 +-
 data/civ1/units.ruleset          |  2 +-
 data/civ2/game.ruleset           |  2 +-
 data/civ2/units.ruleset          |  2 +-
 data/civ2civ3/game.ruleset       |  2 +-
 data/civ2civ3/units.ruleset      |  2 +-
 data/classic/game.ruleset        |  2 +-
 data/classic/units.ruleset       |  2 +-
 data/goldkeep/game.ruleset       |  2 +-
 data/goldkeep/units.ruleset      |  2 +-
 data/granularity/game.ruleset    |  2 +-
 data/granularity/units.ruleset   |  2 +-
 data/multiplayer/game.ruleset    |  2 +-
 data/multiplayer/units.ruleset   |  2 +-
 data/ruledit/comments-3.3.txt    |  4 ++--
 data/sandbox/game.ruleset        |  2 +-
 data/sandbox/units.ruleset       |  2 +-
 data/stub/game.ruleset           |  2 +-
 data/stub/units.ruleset          |  2 +-
 data/webperimental/game.ruleset  |  2 +-
 data/webperimental/units.ruleset |  2 +-
 server/ruleset/ruleload.c        | 19 +++++++++++++++----
 tools/ruleutil/comments.c        | 12 ++++++------
 tools/ruleutil/comments.h        |  2 +-
 tools/ruleutil/rulesave.c        |  8 ++++----
 30 files changed, 57 insertions(+), 46 deletions(-)

diff --git a/common/combat.c b/common/combat.c
index c7b102cbd6..60d7776447 100644
--- a/common/combat.c
+++ b/common/combat.c
@@ -441,12 +441,12 @@ void get_modified_firepower(const struct civ_map *nmap,
     *att_fp = MIN(*att_fp, game.info.low_firepower_badwallattacker);
   }
 
-  /* pearl harbour - defender's firepower is reduced,
-   *                 attacker's is multiplied by two         */
+  /* pearl harbor - defender's firepower is reduced,
+   *                attacker's is multiplied by two         */
   if (unit_has_type_flag(defender, UTYF_BADCITYDEFENDER)
       && tile_city(unit_tile(defender))) {
     *att_fp *= 2;
-    *def_fp = MIN(*def_fp, game.info.low_firepower_pearl_harbour);
+    *def_fp = MIN(*def_fp, game.info.low_firepower_pearl_harbor);
   }
 
   /* 
diff --git a/common/networking/packets.def b/common/networking/packets.def
index 450d628ccd..86d8fd2bd7 100644
--- a/common/networking/packets.def
+++ b/common/networking/packets.def
@@ -572,7 +572,7 @@ PACKET_GAME_INFO = 16; sc, is-info
   BOOL combat_odds_scaled_veterancy;
   BOOL damage_reduces_bombard_rate;
   UINT8 low_firepower_badwallattacker;
-  UINT8 low_firepower_pearl_harbour;
+  UINT8 low_firepower_pearl_harbor;
   UINT8 low_firepower_combat_bonus;
   UINT8 low_firepower_nonnat_bombard;
   UINT8 nuke_pop_loss_pct;
diff --git a/data/alien/game.ruleset b/data/alien/game.ruleset
index 3551c5a238..9ae63afc80 100644
--- a/data/alien/game.ruleset
+++ b/data/alien/game.ruleset
@@ -262,7 +262,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/alien/units.ruleset b/data/alien/units.ruleset
index 67c9d11fe4..eb26aa220c 100644
--- a/data/alien/units.ruleset
+++ b/data/alien/units.ruleset
@@ -360,7 +360,7 @@ flags         = "Missile", "DoesntOccupyTile"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/civ1/game.ruleset b/data/civ1/game.ruleset
index 59def66b1e..c966346669 100644
--- a/data/civ1/game.ruleset
+++ b/data/civ1/game.ruleset
@@ -250,7 +250,7 @@ low_firepower_badwallattacker = 10
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 10
+low_firepower_pearl_harbor = 10
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/civ1/units.ruleset b/data/civ1/units.ruleset
index b52abf63d0..fa7ad2e6e9 100644
--- a/data/civ1/units.ruleset
+++ b/data/civ1/units.ruleset
@@ -335,7 +335,7 @@ flags         = "Missile", "Unreachable", "HutNothing"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/civ2/game.ruleset b/data/civ2/game.ruleset
index 54fe86cbe5..0557440ce0 100644
--- a/data/civ2/game.ruleset
+++ b/data/civ2/game.ruleset
@@ -246,7 +246,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/civ2/units.ruleset b/data/civ2/units.ruleset
index e3cc92688c..bf644ceb16 100644
--- a/data/civ2/units.ruleset
+++ b/data/civ2/units.ruleset
@@ -353,7 +353,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "HutFrighten"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/civ2civ3/game.ruleset b/data/civ2civ3/game.ruleset
index ee94be145f..f2275c42e0 100644
--- a/data/civ2civ3/game.ruleset
+++ b/data/civ2civ3/game.ruleset
@@ -268,7 +268,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/civ2civ3/units.ruleset b/data/civ2civ3/units.ruleset
index 210d19c406..7d67d32275 100644
--- a/data/civ2civ3/units.ruleset
+++ b/data/civ2civ3/units.ruleset
@@ -397,7 +397,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "CanPillage",
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/classic/game.ruleset b/data/classic/game.ruleset
index ceb3cdf89b..9eb64c8903 100644
--- a/data/classic/game.ruleset
+++ b/data/classic/game.ruleset
@@ -263,7 +263,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/classic/units.ruleset b/data/classic/units.ruleset
index 16d3cfaac2..2d76bbdfdd 100644
--- a/data/classic/units.ruleset
+++ b/data/classic/units.ruleset
@@ -363,7 +363,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "HutFrighten"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/goldkeep/game.ruleset b/data/goldkeep/game.ruleset
index 19e6afcd3a..3a995321f0 100644
--- a/data/goldkeep/game.ruleset
+++ b/data/goldkeep/game.ruleset
@@ -266,7 +266,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/goldkeep/units.ruleset b/data/goldkeep/units.ruleset
index 6becc4a548..6d77246f35 100644
--- a/data/goldkeep/units.ruleset
+++ b/data/goldkeep/units.ruleset
@@ -375,7 +375,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "HutFrighten"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/granularity/game.ruleset b/data/granularity/game.ruleset
index 4a0450eff4..10a94760c8 100644
--- a/data/granularity/game.ruleset
+++ b/data/granularity/game.ruleset
@@ -259,7 +259,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/granularity/units.ruleset b/data/granularity/units.ruleset
index a9f711c6e3..19c7352530 100644
--- a/data/granularity/units.ruleset
+++ b/data/granularity/units.ruleset
@@ -310,7 +310,7 @@ flags         = "BuildAnywhere"
 ;                     attacking a city
 ;                     defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/multiplayer/game.ruleset b/data/multiplayer/game.ruleset
index a3daeba185..c100d5fe13 100644
--- a/data/multiplayer/game.ruleset
+++ b/data/multiplayer/game.ruleset
@@ -266,7 +266,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/multiplayer/units.ruleset b/data/multiplayer/units.ruleset
index 5be1b035ca..46cc8c4f7f 100644
--- a/data/multiplayer/units.ruleset
+++ b/data/multiplayer/units.ruleset
@@ -363,7 +363,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "HutFrighten"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/ruledit/comments-3.3.txt b/data/ruledit/comments-3.3.txt
index 93fca267aa..1968084656 100644
--- a/data/ruledit/comments-3.3.txt
+++ b/data/ruledit/comments-3.3.txt
@@ -484,7 +484,7 @@ utypes = "\
 ;                 attacking a city\n\
 ;                 defended by a city wall (or other city building defense)\n\
 ; \"BadCityDefender\" = if attacked while in a city, firepower is set to 1\n\
-;                 and firepower of attacker is doubled (the Pearl Harbour\n\
+;                 and firepower of attacker is doubled (the Pearl Harbor\n\
 ;                 rule)\n\
 ; \"BarbarianOnly\" = only barbarians can build this unit\n\
 ; \"Shield2Gold\" = Switch from shield upkeep to gold upkeep possible\n\
@@ -1488,7 +1488,7 @@ low_firepower_badwallattacker = "\n\
 ; If firepower is already lower than this, it won`t be affected.\
 "
 
-low_firepower_pearl_harbour = "\n\
+low_firepower_pearl_harbor = "\n\
 ; When the defender has BadCityDefender flag, and it`s\n\
 ; defending on a city tile, attacker`s firepower is doubled\n\
 ; and defenders firepower is reduced to this value.\n\
diff --git a/data/sandbox/game.ruleset b/data/sandbox/game.ruleset
index e80494c853..18e8f7637b 100644
--- a/data/sandbox/game.ruleset
+++ b/data/sandbox/game.ruleset
@@ -266,7 +266,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/sandbox/units.ruleset b/data/sandbox/units.ruleset
index d91273fb9c..703250f8e0 100644
--- a/data/sandbox/units.ruleset
+++ b/data/sandbox/units.ruleset
@@ -410,7 +410,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "CanPillage",
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/stub/game.ruleset b/data/stub/game.ruleset
index f3426ca673..136a1306a6 100644
--- a/data/stub/game.ruleset
+++ b/data/stub/game.ruleset
@@ -250,7 +250,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/stub/units.ruleset b/data/stub/units.ruleset
index d8dc881e98..3625800791 100644
--- a/data/stub/units.ruleset
+++ b/data/stub/units.ruleset
@@ -283,7 +283,7 @@ flags         = ""
 ;                     attacking a city
 ;                     defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/data/webperimental/game.ruleset b/data/webperimental/game.ruleset
index 60bc14f672..1aae444e22 100644
--- a/data/webperimental/game.ruleset
+++ b/data/webperimental/game.ruleset
@@ -267,7 +267,7 @@ low_firepower_badwallattacker = 1
 ; defending on a city tile, attacker`s firepower is doubled
 ; and defenders firepower is reduced to this value.
 ; If firepower is already lower than this, it won`t be affected.
-low_firepower_pearl_harbour = 1
+low_firepower_pearl_harbor = 1
 
 ; When the opponent has LowFirepower combat bonus against
 ; a unit, it`s firepower is reduced to this value.
diff --git a/data/webperimental/units.ruleset b/data/webperimental/units.ruleset
index 69db190963..2bc0d48d94 100644
--- a/data/webperimental/units.ruleset
+++ b/data/webperimental/units.ruleset
@@ -367,7 +367,7 @@ flags         = "Unreachable", "DoesntOccupyTile", "HutFrighten"
 ;                 attacking a city
 ;                 defended by a city wall (or other city building defense)
 ; "BadCityDefender" = if attacked while in a city, firepower is set to 1
-;                 and firepower of attacker is doubled (the Pearl Harbour
+;                 and firepower of attacker is doubled (the Pearl Harbor
 ;                 rule)
 ; "BarbarianOnly" = only barbarians can build this unit
 ; "Shield2Gold" = Switch from shield upkeep to gold upkeep possible
diff --git a/server/ruleset/ruleload.c b/server/ruleset/ruleload.c
index d82bb3a050..c742e8e137 100644
--- a/server/ruleset/ruleload.c
+++ b/server/ruleset/ruleload.c
@@ -6935,8 +6935,9 @@ static bool load_ruleset_game(struct section_file *file, bool act,
 
   if (ok) {
     const char *tus_text;
+    int pharbor_default;
 
-    /* section: combat_rules */
+    /* Section: combat_rules */
     game.info.tired_attack
       = secfile_lookup_bool_default(file, RS_DEFAULT_TIRED_ATTACK,
                                     "combat_rules.tired_attack");
@@ -6960,9 +6961,19 @@ static bool load_ruleset_game(struct section_file *file, bool act,
     game.info.low_firepower_badwallattacker
       = secfile_lookup_int_default(file, 1,
                                    "combat_rules.low_firepower_badwallattacker");
-    game.info.low_firepower_pearl_harbour
-      = secfile_lookup_int_default(file, 1,
-                                   "combat_rules.low_firepower_pearl_harbour");
+
+    if (compat->compat_mode && compat->version < RSFORMAT_3_3) {
+      pharbor_default
+        = secfile_lookup_int_default(file, 1,
+                                     "combat_rules.low_firepower_pearl_harbour");
+    } else {
+      pharbor_default = 1;
+    }
+
+    game.info.low_firepower_pearl_harbor
+      = secfile_lookup_int_default(file, pharbor_default,
+                                   "combat_rules.low_firepower_pearl_harbor");
+
     game.info.low_firepower_combat_bonus
       = secfile_lookup_int_default(file, 1,
                                    "combat_rules.low_firepower_combat_bonus");
diff --git a/tools/ruleutil/comments.c b/tools/ruleutil/comments.c
index e9ec720d5c..d16c9f2613 100644
--- a/tools/ruleutil/comments.c
+++ b/tools/ruleutil/comments.c
@@ -80,7 +80,7 @@ static struct {
   char *combat_rules_scaled_veterancy;
   char *combat_rules_damage_reduces_bombard_rate;
   char *combat_rules_low_fp_badwallattacker;
-  char *combat_rules_low_fp_pearl_harbour;
+  char *combat_rules_low_fp_pearl_harbor;
   char *combat_rules_low_fp_combat_bonus;
   char *combat_rules_low_fp_nonnat_bombard;
   char *combat_rules_nuke_pop_loss;
@@ -222,8 +222,8 @@ bool comments_load(void)
                "entrydoc.damage_reduces_bombard_rate");
   comment_load(comments_storage.combat_rules_low_fp_badwallattacker, comment_file,
                "entrydoc.low_firepower_badwallattacker");
-  comment_load(comments_storage.combat_rules_low_fp_pearl_harbour, comment_file,
-               "entrydoc.low_firepower_pearl_harbour");
+  comment_load(comments_storage.combat_rules_low_fp_pearl_harbor, comment_file,
+               "entrydoc.low_firepower_pearl_harbor");
   comment_load(comments_storage.combat_rules_low_fp_combat_bonus, comment_file,
                "entrydoc.low_firepower_combat_bonus");
   comment_load(comments_storage.combat_rules_low_fp_nonnat_bombard, comment_file,
@@ -735,12 +735,12 @@ void comment_combat_rules_low_fp_badwallattacker(struct section_file *sfile)
 }
 
 /**********************************************************************//**
-  Write combat_rules low_firepower_pearl_harbour settings header.
+  Write combat_rules low_firepower_pearl_harbor settings header.
 **************************************************************************/
-void comment_combat_rules_low_fp_pearl_harbour(struct section_file *sfile)
+void comment_combat_rules_low_fp_pearl_harbor(struct section_file *sfile)
 {
   comment_entry_write(sfile,
-                      comments_storage.combat_rules_low_fp_pearl_harbour,
+                      comments_storage.combat_rules_low_fp_pearl_harbor,
                       "combat_rules");
 }
 
diff --git a/tools/ruleutil/comments.h b/tools/ruleutil/comments.h
index 2d61bcdbb8..6a8064c4e5 100644
--- a/tools/ruleutil/comments.h
+++ b/tools/ruleutil/comments.h
@@ -83,7 +83,7 @@ void comment_combat_rules_only_real_fight_veteran(struct section_file *sfile);
 void comment_combat_rules_scaled_veterancy(struct section_file *sfile);
 void comment_combat_rules_damage_reduces_bombard_rate(struct section_file *sfile);
 void comment_combat_rules_low_fp_badwallattacker(struct section_file *sfile);
-void comment_combat_rules_low_fp_pearl_harbour(struct section_file *sfile);
+void comment_combat_rules_low_fp_pearl_harbor(struct section_file *sfile);
 void comment_combat_rules_low_fp_combat_bonus(struct section_file *sfile);
 void comment_combat_rules_low_fp_nonnat_bombard(struct section_file *sfile);
 void comment_combat_rules_nuke_pop_loss(struct section_file *sfile);
diff --git a/tools/ruleutil/rulesave.c b/tools/ruleutil/rulesave.c
index 71d446c7bb..7b4bea363b 100644
--- a/tools/ruleutil/rulesave.c
+++ b/tools/ruleutil/rulesave.c
@@ -1527,11 +1527,11 @@ static bool save_game_ruleset(const char *filename, const char *name)
   }
   save_default_int(sfile, game.info.low_firepower_badwallattacker, 1,
                    "combat_rules.low_firepower_badwallattacker", nullptr);
-  if (game.info.low_firepower_pearl_harbour != 1) {
-    comment_combat_rules_low_fp_pearl_harbour(sfile);
+  if (game.info.low_firepower_pearl_harbor != 1) {
+    comment_combat_rules_low_fp_pearl_harbor(sfile);
   }
-  save_default_int(sfile, game.info.low_firepower_pearl_harbour, 1,
-                   "combat_rules.low_firepower_pearl_harbour", nullptr);
+  save_default_int(sfile, game.info.low_firepower_pearl_harbor, 1,
+                   "combat_rules.low_firepower_pearl_harbor", nullptr);
   if (game.info.low_firepower_combat_bonus != 1) {
     comment_combat_rules_low_fp_combat_bonus(sfile);
   }
diff --git a/ai/default/daimilitary.c b/ai/default/daimilitary.c
index 3eaff62c0c..d22dac4d3a 100644
--- a/ai/default/daimilitary.c
+++ b/ai/default/daimilitary.c
@@ -247,8 +247,8 @@ static int base_assess_defense_unit(struct city *pcity, struct unit *punit,
   fp = unit_type_get(punit)->firepower;
   if (unit_has_type_flag(punit, UTYF_BADCITYDEFENDER)) {
     /* Attacker firepower doubled, defender firepower set to
-     * game.info.low_firepower_pearl_harbour at max. */
-    defense *= MIN(fp, game.info.low_firepower_pearl_harbour);
+     * game.info.low_firepower_pearl_harbor at max. */
+    defense *= MIN(fp, game.info.low_firepower_pearl_harbor);
     defense /= 2;
   } else {
     defense *= fp;
@@ -997,7 +997,7 @@ static adv_want dai_unit_defense_desirability(struct ai_type *ait,
   /* Sea and helicopters often have their firepower set to low firepower when
    * defending. We can't have such units as defenders. */
   if (utype_has_flag(punittype, UTYF_BADCITYDEFENDER)) {
-    fp = MIN(fp, game.info.low_firepower_pearl_harbour);
+    fp = MIN(fp, game.info.low_firepower_pearl_harbor);
   }
   if (((struct unit_type_ai *)utype_ai_data(punittype, ait))->low_firepower) {
     fp = MIN(fp, game.info.low_firepower_combat_bonus);
-- 
2.45.2

